@@ -26,13 +26,13 @@ update_labelled.default <- function(x) {
 #' @export
 update_labelled.labelled <- function(x) {
   # update only previous labelled class, but not objects from Hmisc
-  if (!is.null(attr(x, "labels"))) {
-    if (is.null(attr(x, "na_values")) & is.null(attr(x, "na_range"))) {
-      x <- labelled(x, labels = attr(x, "labels"), label = attr(x, "label"))
+  if (!is.null(attr(x, "labels", exact = TRUE))) {
+    if (is.null(attr(x, "na_values", exact = TRUE)) & is.null(attr(x, "na_range", exact = TRUE))) {
+      x <- labelled(x, labels = attr(x, "labels", exact = TRUE), label = attr(x, "label", exact = TRUE))
     } else {
       x <- labelled_spss(
-        x, na_values = attr(x, "na_values"), na_range = attr(x, "range"),
-        labels = attr(x, "labels"), label = attr(x, "label")
+        x, na_values = attr(x, "na_values", exact = TRUE), na_range = attr(x, "range", exact = TRUE),
+        labels = attr(x, "labels", exact = TRUE), label = attr(x, "label", exact = TRUE)
       )
     }
   }
